{% extends "payments/base.html" %} {% block body %} {% include "payments/_subscription_status.html" %}

## Payment History

Your transaction history

{% if request.user.customer.charges.all %}

Transaction ID | Date | Description | Amount
--- | --- | --- | ---
{% for charge in request.user.customer.charges.all %}
{{ charge.stripe_id }} | {{ charge.created_at }} | {{ charge.customer.plan }} | {% if charge.paid %} Paid ${{ charge.amount|floatformat:"2" }} {% endif %} {% if charge.amount_refunded %} Refunded ${{ charge.amount_refunded|floatformat:"2" }} {% endif %}
{% endfor %}

{% else %}

You have not made any payments yet.

{% endif %} {% endblock %}